@@ -293,11 +293,6 @@ class Client(object):
             for k, v in headers.items():
                 new_headers[k.encode(self.decoding)] = v.encode(self.decoding)
             headers = new_headers
-
-        log.debug('OAuthlib successfully signed the request.')
-        log.debug('URI: %s', uri)
-        log.debug('Headers: %s', headers)
-        log.debug('Body: %s', body)
         return uri, headers, body
 
 
@@ -725,7 +720,7 @@ class Server(object):
               request_token=None, access_token=None):
 
               return ((client_key, timestamp, nonce, request_token or access_token)
-                       in self.nonces_and_timestamps_database)
+                       not in self.nonces_and_timestamps_database)
         """
         raise NotImplementedError("Subclasses must implement this function.")
 
